# On Being Together

<pre id="on_being_together">
When being together, especially if things go wrong,  
we acknowledge and work through differences.  
In so doing, we transform and enlarge each other.

To nurture our mutual growth,

    this is a place of  
        learning, understanding, and sharing;  

    this is a place to  
        affirm tolerance and compassion;  

    this is a place for  
        collaborative creativity.

All the aspects of yourself you choose to bring to this place  
are welcome here.

Reciprocate! Welcome, embrace and learn from others  
(even in the face of apparent hostility or misunderstanding).

Thoughtful, careful and courteous contributions are a gift,
and never knowingly diminish, dehumanize or harm others.

To act against this spirit invites ostracism, 
a loss that diminishes us all.

Thank you.
</pre>

---

From [here](https://github.com/ntoll/being_together).

[Here's why](https://ntoll.org/article/on-being-together/).